==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ar.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "إدارة معلمات صندوق الصور صور و");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "إدارة معرض");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "كامل حجم عرض صورة");
define('MANAGE_GALLERY_FULL_HEIGHT', "كامل حجم الصورة الطول");
define('MANAGE_GALLERY_THUMB_WIDTH', "الصور المصغرة عرض صورة");
define('MANAGE_GALLERY_THUMB_HEIGHT', "صورة مصغرة الطول");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "الحفاظ على الإبهام نسبة الارتفاع");
define('MANAGE_GALLERY_SHOW_TITLES', "مشاهدة العناوين");
define('MANAGE_GALLERY_DISABLE_SORT', "تعطيل ترتيب");
define('MANAGE_GALLERY_DELETE_IMAGE', "حذف صورة");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "حفظ ترتيب");
define('MANAGE_GALLERY_PUBLISH_MSG', "انقر على &quot;تحديث&quot; لنشر <br /> الصور التي يتم تحميلها.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "وقد تم تحجيمها جميع الصور وتم حفظ إعدادات.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "كان هناك خطأ تغيير حجم الصور أو إعدادات إنقاذ.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "وقد تم تحميل صورة الخاص بك (ق).");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "كان هناك خطأ تحميل الصور الخاصة بك (ق).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "الملف الذي تحاول تحميله ليس صورة.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "الملف الذي تحاول تحميله كبير جدا.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "تم حفظ اللقب.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "هل أنت متأكد أنك تريد حذف صورة");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تم حذف الصورة.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "كان هناك خطأ حذف الصورة.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "إنقاذ المعلمات وتغيير حجم الصور، يرجى الانتظار ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "تحميل الرجاء الانتظار ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "لم يتم حفظ الترتيب. هل تريد حفظ ترتيب؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "تم حفظ ترتيب الصور القبيل.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "كان هناك خطأ في حفظ النوع صورة.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ar.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "إدارة معلمات صندوق الصور صور و");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "إدارة معرض");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "كامل حجم عرض صورة");
define('MANAGE_GALLERY_FULL_HEIGHT', "كامل حجم الصورة الطول");
define('MANAGE_GALLERY_THUMB_WIDTH', "الصور المصغرة عرض صورة");
define('MANAGE_GALLERY_THUMB_HEIGHT', "صورة مصغرة الطول");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "الحفاظ على الإبهام نسبة الارتفاع");
define('MANAGE_GALLERY_SHOW_TITLES', "مشاهدة العناوين");
define('MANAGE_GALLERY_DISABLE_SORT', "تعطيل ترتيب");
define('MANAGE_GALLERY_DELETE_IMAGE', "حذف صورة");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "حفظ ترتيب");
define('MANAGE_GALLERY_PUBLISH_MSG', "انقر على &quot;تحديث&quot; لنشر <br /> الصور التي يتم تحميلها.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "وقد تم تحجيمها جميع الصور وتم حفظ إعدادات.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "كان هناك خطأ تغيير حجم الصور أو إعدادات إنقاذ.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "وقد تم تحميل صورة الخاص بك (ق).");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "كان هناك خطأ تحميل الصور الخاصة بك (ق).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "الملف الذي تحاول تحميله ليس صورة.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "الملف الذي تحاول تحميله كبير جدا.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "تم حفظ اللقب.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "هل أنت متأكد أنك تريد حذف صورة");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تم حذف الصورة.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "كان هناك خطأ حذف الصورة.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "إنقاذ المعلمات وتغيير حجم الصور، يرجى الانتظار ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "تحميل الرجاء الانتظار ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "لم يتم حفظ الترتيب. هل تريد حفظ ترتيب؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "تم حفظ ترتيب الصور القبيل.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "كان هناك خطأ في حفظ النوع صورة.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "الملف الذي تحاول تحميله أكبر من إعدادات PHP &quot;upload_max_filesize&quot; أو &quot;post_max_size&quot;. اتصل بمسؤول النظام لزيادة هذه الحدود.");
?>
